Params

Struct Params 

pub struct Params {
    pub oss_device: *const c_char,
    pub alsa_device: *const c_char,
    pub nas_server: *const c_char,
    pub pulse_device: *const c_char,
    pub pulse_min_length: *const c_char,
    /* private fields */
}
Server settable audio output parameters

Fields

oss_device: *const c_charalsa_device: *const c_charnas_server: *const c_charpulse_device: *const c_charpulse_min_length: *const c_char

Implementations

Source

impl Params

pub const FIELDS: [&'static str; 5]

pub unsafe fn set_by_name(&mut self, name: &str, value: *const c_char) -> bool

Helper method to update param struct entries by name

Safety

Previous value at the field potentially replaced must either be ptr::null() or a pointer allocated by free. In other words don’t ever store invalid or non-malloc’d pointers in the struct.

pub fn get_by_name(&self, name: &str) -> Option<*const c_char>

Helper method to retrieve param struct entries by name