#[repr(C)]pub enum VoiceType {
Male1 = 1,
Male2 = 2,
Male3 = 3,
Female1 = 4,
Female2 = 5,
Female3 = 6,
ChildMale = 7,
ChildFemale = 8,
Unspecified = -1,
}Expand description
Symbolic voice type
These values are approximations for human display, output modules are free to interpret their meanings in any way they consider sensible.
Variants
Male1 = 1
Male2 = 2
Male3 = 3
Female1 = 4
Female2 = 5
Female3 = 6
ChildMale = 7
ChildFemale = 8
Unspecified = -1