pub unsafe extern "C" fn module_audio_set(
var: *const c_char,
val: *const c_char,
) -> c_intExpand description
Set audio parameter
Your module implementation must export it’s own version of this
function, unless your build system builds and links with its own
version of module-utils.c from the speech-dispatcher distribution.
Note that this function is only required when using client audio playback. Implementations relying on server playback being available may stub this.
#[unsafe(no_mangle)]
unsafe extern "C" fn module_audio_set(var: *const raw::c_char, val: *const raw::c_char) -> raw::c_int {
-1 // Stub implementation
}