module_list_voices

Function module_list_voices 

pub extern "C" fn module_list_voices() -> *const *const Voice
List voices

Response is a NULL-terminated, malloc’d array of pointers to each configured module voice. See the Voice data structure for the format of indivial voices.

Returning NULL from the function will abort module startup.

Your module implementation must export it’s own version of this function as:

#[unsafe(no_mangle)]
extern "C" fn module_list_voices() -> *const *const Voice {
    // Stub implementation
    unsafe {
        let res = libc::malloc(size_of<*const Voice>());
        assert!(res != ptr::null_mut());
        *res = ptr::null();
        res
    }
}