module_loglevel_set

Function module_loglevel_set 

pub unsafe extern "C" fn module_loglevel_set(
    var: *const c_char,
    val: *const c_char,
) -> c_int
Set logging subsystem parameter

Generally var will only ever be the string “log_level” and val will be an integer string in the range of 0 to 5, see section 2.4.7 (“Log Levels”) of the speech-dispatcher manual for the list of standard logging levels.

Your module implementation must export it’s own version of this function, unless your build system builds and links with its own version of module-utils.c from the speech-dispatcher distribution.

#[unsafe(no_mangle)]
unsafe extern "C" fn module_loglevel_set(var: *const raw::c_char, val: *const raw::c_char) -> raw::c_int {
    // Implementation
}