module_set

Function module_set 

pub unsafe extern "C" fn module_set(
    var: *const c_char,
    val: *const c_char,
) -> c_int
Set parameter, see the SET command of section 5.2.2 (“Communication Protocol for Output Modules”) of the speech-dispatcher manual for a list of standard properties

Your module implementation must export it’s own version of this function, unless your build system builds and links with its own version of module-utils.c from the speech-dispatcher distribution.

#[unsafe(no_mangle)]
unsafe extern "C" fn module_set(var: *const raw::c_char, val: *const raw::c_char) -> raw::c_int {
    // Implementation
}