pub extern "C" fn module_audio_set_server()Expand description
Notify the library that the module will send its audio as wave events
to the server using module_tts_output_server
pub extern "C" fn module_audio_set_server()Notify the library that the module will send its audio as wave events
to the server using module_tts_output_server