pub unsafe extern "C" fn module_debug(
enable: c_int,
file: *const c_char,
) -> c_intExpand description
Enable or disable debugging into the given file
The enable parameter is a boolean integer with values 0 (false) or
1 (true) to disable or enable (respectively) verbose file debugging.
The file parameter is the NUL-terminated path where the debug file
should be written to.
Your module implementation must export it’s own version of this
function, unless your build system builds and links with its own
version of module-utils.c from the speech-dispatcher distribution.
#[unsafe(no_mangle)]
unsafe extern "C" fn module_debug(enable: raw::c_int, file: *const raw::c_char) -> raw::c_int {
// Implementation
}