pub extern "C" fn module_speak_ok()Expand description
Callback for module_speak_sync to confirm the data is OK before
actually synthesizing
The server may send stop requests, so resetting the stop state must be done before calling this.
pub extern "C" fn module_speak_ok()Callback for module_speak_sync to confirm the data is OK before
actually synthesizing
The server may send stop requests, so resetting the stop state must be done before calling this.